@@ -46,11 +46,21 @@ The socket your mysql is using. DEFAULT: /tmp/mysql.sock
 
 Database contain UMLS DEFAULT: umls
 
-=head4 --help
+=head3 --forcerun
+
+This option will bypass any command prompts such as asking 
+if you would like to continue with the index creation. 
+
+=head3 --verbose
+
+This option will print out the table information to the 
+config file that you specified.
+
+=head3 --help
 
 Displays the quick summary of program options.
 
-=head4 --version
+=head3 --version
 
 Displays the version information.
 
@@ -117,7 +127,7 @@ this program; if not, write to:
 use UMLS::Interface;
 use Getopt::Long;
 
-GetOptions( "version", "help", "username=s", "password=s", "hostname=s", "database=s", "socket=s", "config=s", "forcerun" );
+GetOptions( "version", "help", "username=s", "password=s", "hostname=s", "database=s", "socket=s", "config=s", "forcerun", "verbose" );
 
 
 #  if help is defined, print out help
@@ -158,6 +168,9 @@ if(defined $opt_config) {
 if(defined $opt_forcerun) {
     $option_hash{"forcerun"} = $opt_forcerun;
 }
+if(defined $opt_verbose) {
+    $option_hash{"verbose"} = $opt_verbose;
+}
 if(defined $opt_username and defined $opt_password) {
     $option_hash{"driver"}   = "mysql";
     $option_hash{"database"} = $database;
@@ -252,6 +265,14 @@ sub showHelp() {
     print "--socket STRING          Socket used by mysql (DEFAULT: /tmp.mysql.sock)\n\n";
 
     print "--config FILE            Configuration file\n\n";
+   
+    print "--forcerun               This option will bypass any command \n";
+    print "                         prompts such as asking if you would \n";
+    print "                         like to continue with the index \n";
+    print "                         creation. \n\n";
+
+    print "--verbose                This option prints out the path information\n";
+    print "                         to a file in your config directory.\n\n";    
 
     print "--version                Prints the version number\n\n";
  
@@ -262,7 +283,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: findMinimumCuiDepth.pl,v 1.5 2009/10/13 14:07:10 btmcinnes Exp $';
+    print '$Id: findMinimumCuiDepth.pl,v 1.3 2009/10/30 16:14:14 btmcinnes Exp $';
     print "\nCopyright (c) 2008, Ted Pedersen & Bridget McInnes\n";
 }
 
